@@ -1,14 +1,15 @@
 package resources
 
 import (
+	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/rebuy-de/aws-nuke/pkg/types"
 )
 
 type EC2VPC struct {
-	svc       *ec2.EC2
-	vpc       *ec2.Vpc
+	svc *ec2.EC2
+	vpc *ec2.Vpc
 }
 
 func init() {
@@ -26,14 +27,34 @@ func ListEC2VPCs(sess *session.Session) ([]Resource, error) {
 	resources := make([]Resource, 0)
 	for _, vpc := range resp.Vpcs {
 		resources = append(resources, &EC2VPC{
-			svc:       svc,
-			vpc:       vpc,
+			svc: svc,
+			vpc: vpc,
 		})
 	}
 
 	return resources, nil
 }
 
+func DefaultVpc(svc *ec2.EC2) *ec2.Vpc {
+	resp, err := svc.DescribeVpcs(&ec2.DescribeVpcsInput{
+		Filters: []*ec2.Filter{
+			{
+				Name:   aws.String("is-default"),
+				Values: aws.StringSlice([]string{"true"}),
+			},
+		},
+	})
+	if err != nil {
+		return nil
+	}
+
+	if len(resp.Vpcs) == 0 {
+		return nil
+	}
+
+	return resp.Vpcs[0]
+}
+
 func (e *EC2VPC) Remove() error {
 	params := &ec2.DeleteVpcInput{
 		VpcId: e.vpc.VpcId,
